frida_query_builder library
A fluent SQL query builder for Dart.
This library provides a set of classes and extensions to build SQL statements (SELECT, INSERT, UPDATE, DELETE, CREATE, ALTER) using a fluent and intuitive API.
Classes
- AddColumn
- Alter
- And
- Avg
- Between
- Column
- Represents a base column definition for a table.
- ColumnBlob
- ColumnInteger
- ColumnReal
- ColumnText
- Count
- Create
- Represents an SQL CREATE TABLE statement.
- CreateIndex
- Represents an SQL CREATE INDEX statement.
- Criterion
- CriterionLogic
- CurrentTimestamp
- Delete
- Represents an SQL DELETE statement.
- Divide
- DropColumn
- DropIndex
- Represents an SQL DROP INDEX statement.
- DropTable
- Equals
- Field
- Represents a field in a database table.
- ForeignKey
- FridaQueryBuilder
- Main entry point for the query builder.
- GreaterEqualThan
- GreaterThan
- Grouping
- In
- Insert
- Represents an SQL INSERT statement.
- Join
- Represents an SQL JOIN clause.
- Length
- LessEqualThan
- LessThan
- Like
- Max
- Min
- Minus
- Modulo
- Multiply
- Not
- NotEquals
- Operator
- Or
- Plus
- RenameColumn
- RenameTable
- Select
- Represents an SQL SELECT statement.
- Sort
- Represents a sort configuration for an ORDER BY clause.
- Statement
- Represents a base SQL statement.
- Subquery
- Represents a subquery that can be used in other statements.
- Sum
- Update
- Represents an SQL UPDATE statement.
Enums
- ForeignKeyAction
- JoinType
- OrderBy
- Represents the order of sorting.
Extensions
- FieldExtensions on Field
- Extensions for Field to create Criterion objects fluently.
- FridaCriteriaExtensions on Criterion
- Extensions for Criterion to combine them using logical operators.
- FridaDouble on double
- Extensions for double to easily create Field objects (useful for numeric fields).
- FridaInt on int
- Extensions for int to easily create Field objects (useful for numeric fields).
- FridaStatementExtension on Statement
- Extension to provide a convenient build method on any Statement.
- FridaString on String
- Extensions for String to easily create Field objects.
- JoinTypeExtension on JoinType
- OrderByExtension on OrderBy