Count class
- Inheritance
- Available extensions
Constructors
- Count(dynamic field)
Properties
- alias ↔ String?
-
Optional alias for the field.
getter/setter pairinherited
- asc → Sort
-
Available on Field, provided by the FieldExtensions extension
Creates a Sort in ascending order.no setter - desc → Sort
-
Available on Field, provided by the FieldExtensions extension
Creates a Sort in descending order.no setter - field ↔ String
-
The name of the field.
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
as(
String alias) → Field -
Sets an
aliasfor this field.inherited -
between(
Object? start, Object? end) → Between -
Available on Field, provided by the FieldExtensions extension
Creates a Between criterion:this BETWEEN start AND end. -
divide(
Field other) → Divide -
Creates a Divide operator:
this / other.inherited -
equals(
Object? value, {bool? valueQuoted}) → Equals -
Available on Field, provided by the FieldExtensions extension
Creates an Equals criterion:this = value. -
greaterEqualThan(
Object? value) → GreaterEqualThan -
Available on Field, provided by the FieldExtensions extension
Creates a GreaterEqualThan criterion:this >= value. -
greaterThan(
Object? value) → GreaterThan -
Available on Field, provided by the FieldExtensions extension
Creates a GreaterThan criterion:this > value. -
isIn(
List< Object> values) → In -
Available on Field, provided by the FieldExtensions extension
Creates an In criterion:this IN (values). -
lessEqualThan(
Object? value) → LessEqualThan -
Available on Field, provided by the FieldExtensions extension
Creates a LessEqualThan criterion:this <= value. -
lessThan(
Object? value) → LessThan -
Available on Field, provided by the FieldExtensions extension
Creates a LessThan criterion:this < value. -
like(
Object? value) → Like -
Available on Field, provided by the FieldExtensions extension
Creates a Like criterion:this LIKE value. -
minus(
Field other) → Minus -
Creates a Minus operator:
this - other.inherited -
modulo(
Field other) → Modulo -
Creates a Modulo operator:
this % other.inherited -
multiply(
Field other) → Multiply -
Creates a Multiply operator:
this * other.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notEquals(
Object? value, {bool? valueQuoted}) → NotEquals -
Available on Field, provided by the FieldExtensions extension
Creates a NotEquals criterion:this <> value. -
plus(
Field other) → Plus -
Creates a Plus operator:
this + other.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited