NotEquals class

Inheritance
Available extensions

Constructors

NotEquals(Object? firstField, Object? secondField, {bool firstFieldQuoted = true, bool secondFieldQuoted = true})

Properties

criterionOperator String
getter/setter pairinherited
firstField Object?
getter/setter pairinherited
firstFieldQuoted bool
finalinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondField Object?
getter/setter pairinherited
secondFieldQuoted bool
finalinherited

Methods

accept<T>(StatementVisitor<T> visitor) → T
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
not() Not

Available on Criterion, provided by the FridaCriteriaExtensions extension

Negates the criterion with a Not operator.
toString() String
A string representation of this object.
inherited

Operators

operator &(Criterion other) And

Available on Criterion, provided by the FridaCriteriaExtensions extension

Combines two criteria with an And operator.
operator ==(Object other) bool
The equality operator.
inherited
operator |(Criterion other) Or

Available on Criterion, provided by the FridaCriteriaExtensions extension

Combines two criteria with an Or operator.